@@ -24,19 +24,9 @@
 #' @return list
 #'
 #' @keywords internal
-reconstruct_algorithm <- function(pattern,
-                                  method,
-                                  n_random,
-                                  e_threshold,
-                                  max_runs,
-                                  no_change,
-                                  annealing,
-                                  weights,
-                                  r_length,
-                                  r_max,
-                                  stoyan,
-                                  verbose,
-                                  plot){
+reconstruct_algorithm <- function(pattern, method, n_random, e_threshold, max_runs,
+                                  no_change, annealing, weights, r_length, r_max,
+                                  stoyan, verbose, plot){
 
   # check if n_random is >= 1
   if (n_random < 1) {
@@ -90,14 +80,14 @@ reconstruct_algorithm <- function(pattern,
 
   # create empty lists for results
   energy_list <- vector("list", length = n_random)
-  iterations_list <- vector("list", length = n_random)
-  stop_criterion_list <- as.list(rep("max_runs", times = n_random))
+  iterations_vec <- vector(mode = "numeric", length = n_random)
+  stop_criterion_vec <- rep("max_runs", times = n_random)
   result_list <- vector("list", length = n_random)
 
   # set names
   names(energy_list) <- names_randomization
-  names(iterations_list) <- names_randomization
-  names(stop_criterion_list) <- names_randomization
+  names(iterations_vec) <- names_randomization
+  names(stop_criterion_vec) <- names_randomization
   names(result_list) <- names_randomization
 
   # calculate summary functions
@@ -286,8 +276,8 @@ reconstruct_algorithm <- function(pattern,
       if (energy <= e_threshold || energy_counter > no_change) {
 
         # set stop criterion due to energy
-        stop_criterion_list[[i]] <- ifelse(test = energy <= e_threshold,
-                                           yes = "e_threshold", no = "no_change")
+        stop_criterion_vec[i] <- ifelse(test = energy <= e_threshold,
+                                        yes = "e_threshold", no = "no_change")
 
         break
 
@@ -302,7 +292,7 @@ reconstruct_algorithm <- function(pattern,
     }
 
     # remove NAs if stopped due to energy
-    if (stop_criterion_list[[i]] %in% c("e_threshold", "no_change")) {
+    if (stop_criterion_vec[i] %in% c("e_threshold", "no_change")) {
 
       energy_df <- energy_df[1:j, ]
 
@@ -310,7 +300,7 @@ reconstruct_algorithm <- function(pattern,
 
     # save results in lists
     energy_list[[i]] <- energy_df
-    iterations_list[[i]] <- j
+    iterations_vec[i] <- j
     result_list[[i]] <- simulated
 
   }
@@ -321,8 +311,8 @@ reconstruct_algorithm <- function(pattern,
   # combine to one list
   reconstruction <- list(randomized = result_list, observed = pattern,
                          method = method, energy_df = energy_list,
-                         stop_criterion = stop_criterion_list,
-                         iterations = iterations_list)
+                         stop_criterion = stop_criterion_vec,
+                         iterations = iterations_vec, param = NA)
 
   return(reconstruction)
 }
