@@ -18,6 +18,8 @@ globalVariables(c("count",
                   "hi",
                   "iso",
                   "lo",
+                  "mark",
+                  "obs_window",
                   "r",
                   "summary_function",
                   "theo",
